@@ -146,7 +146,7 @@ The default value is C<20>.
 A template for construction of squashed messages. See
 L<App::KGB::Client/message-template> for details.
 
-The default is C<${{author-name}}${ ({author-login})}${ {branch}}${ {commit}}${ {project}/}${{module}}${ {log}}>.
+The default is C<${{author-name}}${ {branch}}${ {commit}}${ {module}}${ {log}}>.
 
 =item tag-squash-threshold I<number>
 
@@ -162,7 +162,7 @@ The default value is C<5>.
 A template for construction of squashed tags messages. See
 L<App::KGB::Client/message-template> for details.
 
-The default is C<${{author-name}}${ ({author-login})}${ {project}/}${{module}}${ {log}}>.
+The default is C<${{author-name}}${ {module}}${ {log}}>.
 
 =item enable-branch-ff-notification I<bool>
 
@@ -218,15 +218,15 @@ sub new {
     if ( my $smt = $self->_git->config('kgb.squash-message-template') ) {
         $self->squash_msg_template($smt);
     }
-    $self->squash_msg_template('${{author-name}}${ ({author-login})}${ {branch}}${ {commit}}${ {project}/}${{module}}${ {log}}')
+    $self->squash_msg_template('${{author-name}}${ {branch}}${ {commit}}${ {module}}${ {log}}')
         unless $self->squash_msg_template;
     if ( my $tsmt = $self->_git->config('kgb.tag-squash-message-template') ) {
         $self->tag_squash_msg_template($tsmt);
     }
     $self->tag_squash_msg_template(
-        '${{author-name}}${ ({author-login})}${ {project}/}${{module}}${ {log}}'
+        '${{author-name} }${{module}}${ {log}}'
     ) unless $self->tag_squash_msg_template;
-    $self->branch_ff_msg_template('${{author-name}}${ ({author-login})}${ {branch}}${ {commit}}${ {project}/}${{module}} fast-forward')
+    $self->branch_ff_msg_template('${{author-name}}${ {branch}}${ {commit}}${ {module}} fast-forward')
         unless $self->branch_ff_msg_template;
 
     my $ebfn = $self->_git->config('kgb.enable-branch-ff-notification');
@@ -237,6 +237,62 @@ sub new {
     $self->enable_branch_ff_notification(1)
         unless defined $self->enable_branch_ff_notification;
 
+    return $self;
+}
+
+sub _parse_reflog {
+    my $self = shift;
+
+    # read changeset data from a file
+    $self->changesets( [] );
+    my $fh;
+    open( $fh, $self->reflog // '-' )
+        or die "open(" . $self->reflog // '-' . "): $!";
+        # in order for '-' to open STDIN, we must use two-argument form of
+        # open(). see 'perldoc -f open'
+    while (<$fh>) {
+        chomp;
+        my @cs = split( /\s+/, $_ );
+        @cs == 3
+            or confess
+            "Invalid data on row $.. Must contain three space-separated words";
+        push @{ $self->changesets }, \@cs;
+    }
+    close $fh;
+
+    die "Reflog was empty. Broken git post-receive hook?\n"
+        unless @{ $self->{changesets} };
+}
+
+=head1 METHODS
+
+=over
+
+=item describe_commit
+
+Returns an instance of L<App::KGB::Change> class for each commit. Returns
+B<undef> when all commits were processed.
+
+=cut
+
+sub describe_commit {
+    my $self = shift;
+
+    $self->_detect_commits unless defined( $self->_commits );
+
+    return shift @{ $self->_commits };
+}
+
+sub _reset {
+    my $self = shift;
+
+    $self->_commits(undef);
+    $self->changesets(undef);
+}
+
+sub _detect_commits {
+    my $self = shift;
+
     if ( defined( $self->old_rev // $self->new_rev // $self->refname ) ) {
 
         # single commit
@@ -282,52 +338,6 @@ sub new {
         $self->_parse_reflog;
     }
 
-    return $self;
-}
-
-sub _parse_reflog {
-    my $self = shift;
-
-    # read changeset data from a file
-    $self->changesets( [] );
-    my $fh;
-    open( $fh, $self->reflog // '-' )
-        or die "open(" . $self->reflog // '-' . "): $!";
-        # in order for '-' to open STDIN, we must use two-argument form of
-        # open(). see 'perldoc -f open'
-    while (<$fh>) {
-        chomp;
-        my @cs = split( /\s+/, $_ );
-        @cs == 3
-            or confess
-            "Invalid data on row $.. Must contain three space-separated words";
-        push @{ $self->changesets }, \@cs;
-    }
-    close $fh;
-}
-
-=head1 METHODS
-
-=over
-
-=item describe_commit
-
-Returns an instance of L<App::KGB::Change> class for each commit. Returns
-B<undef> when all commits were processed.
-
-=cut
-
-sub describe_commit {
-    my $self = shift;
-
-    $self->_detect_commits unless defined( $self->_commits );
-
-    return shift @{ $self->_commits };
-}
-
-sub _detect_commits {
-    my $self = shift;
-
     $self->_commits([]);
 
     $self->_describe_branch_updates;
